@@ -54,8 +54,6 @@ Note that if you don't pass anything, errors will be sent to /dev/null (or a tem
 use strict;
 use warnings;
 
-use UNIVERSAL qw/isa can/;
-
 # Hold our error filehandle
 our $error_fh;
 
@@ -173,6 +171,8 @@ Examples:
 
 This scheme works quite well because HtmlUnit itself just so happens to not overlap their method names between different classes. Lucky us!
 
+Note: We also call ->toArray on results if needed. Probably at some point we'll get ALL array-like results from HtmlUnit to auto-execute ->toArray.
+
 =cut
 
 # This will make us act a bit more like Mechanize
@@ -188,17 +188,23 @@ sub AUTOLOAD {
     my $page = $window && $window->getEnclosedPage;
     my $element = $page && $page->getFocusedElement;
 
+    my $result;
 		if($browser && $browser->can($method)) {
-			return $browser->$method(@_);
+			$result = $browser->$method(@_);
 		} elsif($window && $window->can($method)) {
-			return $window->$method(@_);
+			$result = $window->$method(@_);
 		} elsif($page && $page->can($method)) {
-			return $page->$method(@_);
+			$result = $page->$method(@_);
 		} elsif($element && $element->can($method)) {
-			return $element->$method(@_);
+			$result = $element->$method(@_);
 		} else {
 			die "Method $method not found!";
 		}
+    if(ref $result && $result->can('toArray')) {
+      return $result->toArray;
+    } else {
+      return $result;
+    }
 	};
 	if($@ && ref($@) =~ /Exception/) {
 		print STDERR "HtmlUnit ERROR: " . $@->getMessage . "\n";
